<?php

namespace Drupal\webt;

use Drupal\Core\Url;

/**
 * Service that generates public URL for assets (e.g. images).
 */
class AssetManager {

	/**
	 * Retrieves full asset URL from relative path
	 *
	 * @param string $relative_path Path to asset.
	 * @return string
	 */
	public function getAssetUrl( $relative_path ) {
		$module_path = \Drupal::service( 'module_handler' )
			->getModule( 'webt' )
			->getPath();

		$language_manager = \Drupal::languageManager();
		$current_language = $language_manager->getCurrentLanguage()->getId();
		$home_url         = Url::fromRoute( '<front>', array(), array( 'absolute' => true ) )->toString();
		// Remove language code from URL if present.
		if ( str_ends_with( $home_url, '/' . $current_language ) ) {
			$home_url = substr( $home_url, 0, strlen( $home_url ) - strlen( $current_language ) );
		}

		return "$home_url/$module_path/$relative_path";
	}
}
