<?php

namespace Drupal\webt\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Render\FormattableMarkup;

/**
 * Controller that generates content for About section
 */
class AboutTabController extends ControllerBase {

	/**
	 * Generate markup
	 *
	 * @return array
	 */
	public function content() {
		$about_heading   = t( 'About WEB-T module' );
		$about_content   = t( 'WEB-T is a module that allows you to translate your Drupal website content using machine translation. It comes with a default translation provider, eTranslation, but can be configured to use custom providers.' );

		$configure_content = new FormattableMarkup(
			t( "See how to <a target='_blank' href='@link'>configure and use this plugin</a>." ),
			array(
				'@link' => 'https://website-translation.language-tools.ec.europa.eu/solutions/drupal_en',
			)
		);

		$more_info_heading = t( 'More information' );
		$more_info_content = t( 'WEB-T is a part of European Multilingual Web (EMW) project by EC' );
		$learn_more        = t( 'Learn more' );
		$learn_more_link   = 'https://website-translation.language-tools.ec.europa.eu/web-t-connecting-languages-0_en';

		$asset_manager     = \Drupal::service( 'webt.asset_manager' );
		$ec_logotype_url   = $asset_manager->getAssetUrl( 'images/ec_logotype.svg' );
		$webt_logotype_url = $asset_manager->getAssetUrl( 'images/webt_logotype.svg' );

		$text = "
			<h5>$about_heading</h5>
			<p>
				$about_content
			</p>
			<p>
				$configure_content
			</p>
			<h5>$more_info_heading</h5>
			<p>
				$more_info_content (<a target='_blank' href='$learn_more_link'>$learn_more</a>).
			</p>
			<p>
				<img alt='EC logotype' class='logotypes' src='$ec_logotype_url' />
				<img alt='WEBT logotype' class='logotypes' src='$webt_logotype_url' id='webt_logtype' />
			</p>
			";

		return array(
			'#markup'   => $text,
			'#attached' => array(
				'library' => array(
					'webt/about_tab.style',
				),
			),
		);
	}

}
